==> abg_utils-7.0.1.tar.gz: lib/src/ui/dialogs/dialogs.dart <==
import 'package:flutter/material.dart';
import '../../../abg_utils.dart';

//
// классически квадратик посередине
//
openDialogYesNo(Function(String) callback, BuildContext context,
    String stringText, String text1, String text2){
  EasyDialog(
      colorBackground: aTheme.darkMode ? Colors.black : Colors.white,
      body: Column(
        children: [
          Text(stringText),
          SizedBox(height: 40,),
          Row(
            children: [
              Flexible(child: button2(text1,
                  aTheme.mainColor,
                      (){
                    Navigator.pop(context); // close dialog
                    callback("text1");
                  })),
              SizedBox(width: 10,),
              Flexible(child: button2(text2,
                  aTheme.mainColor, (){
                    Navigator.pop(context); // close dialog
                    callback("text2");
                  })),
            ],
          )
        ],
      )
  ).show(context);
}

openDialogYesNoBody(Function(String) callback, BuildContext context,
    String stringText, String text1, String text2){
  return Column(
        children: [
          Text(stringText),
          SizedBox(height: 40,),
          Row(
            children: [
              Flexible(child: button2(text1,
                  aTheme.mainColor,
                      (){

                    callback("text1");
                  })),
              SizedBox(width: 10,),
              Flexible(child: button2(text2,
                  aTheme.mainColor, (){
                    Navigator.pop(context); // close dialog
                    callback("text2");
                  })),
            ],
          )
        ],
      );
}

==> abg_utils-7.0.2.tar.gz: lib/src/ui/dialogs/dialogs.dart <==
import 'package:flutter/material.dart';
import '../../../abg_utils.dart';

//
// классически квадратик посередине
//
openDialogYesNo(Function(String) callback, BuildContext context,
    String stringText, String text1, String text2){
  EasyDialog(
      colorBackground: aTheme.darkMode ? Colors.black : Colors.white,
      body: Column(
        children: [
          Text(stringText),
          SizedBox(height: 40,),
          Row(
            children: [
              Flexible(child: button2(text1,
                  aTheme.mainColor,
                      (){
                    Navigator.pop(context); // close dialog
                    callback("text1");
                  })),
              SizedBox(width: 10,),
              Flexible(child: button2(text2,
                  aTheme.mainColor, (){
                    Navigator.pop(context); // close dialog
                    callback("text2");
                  })),
            ],
          )
        ],
      )
  ).show(context);
}

openDialogYesNoBody(Function(String) callback,
    String stringText, String text1, String text2){
  return Column(
        children: [
          Text(stringText),
          SizedBox(height: 40,),
          Row(
            children: [
              Flexible(child: button2(text1,
                  aTheme.mainColor,
                      (){
                    closeDialog();
                    callback("text1");
                  })),
              SizedBox(width: 10,),
              Flexible(child: button2(text2,
                  aTheme.mainColor, (){
                    closeDialog();
                    callback("text2");
                  })),
            ],
          )
        ],
      );
}
